#ifndef SERVICE_FIX_SET_H
#define SERVICE_FIX_SET_H
#include "data_config.h"
#include "ui_config.h"
#include "comm.h"

extern void fs_service_get_show_ui_data(PageCtx *ctx ,u8 menu_sel_idx , u8 item_sel_idx , GeneralListPageConfig_t *config);


extern uint16_t fs_service_get_menu_len_by_page(PageType cur_page);
extern uint16_t fs_service_get_items_len_by_page(PageType cur_page , u8 menu_sel_idx);
extern bool fs_service_is_menu_enabled(PageCtx *ctx, u8 menu_sel_idx);

extern void fs_service_get_sel_setval_data(PageCtx *ctx ,UiSetValueOptDef *ui_opt);
extern bool fs_service_modify_menu_data(DataModule module, uint8_t menu_id, uint8_t data_id, float value);
extern bool fs_service_check_diff(void);
extern bool fs_service_is_trasw_yb_selected(PageCtx *ctx);

extern bool fs_set_data_to_system(DataModule module);
extern void fs_service_restore_default_values(DataModule module);
#endif // SERVICE_FIX_SET_H